@@ -10,7 +10,9 @@ class OfficialEntries(EntriesGroup):
 
     commands = {
         "install missing dependencies of PythonSearch": {
-            "new-window-non-cli": True,
-            "cmd": "python_search  install_missing_dependencies",
+            "cli_cmd": "python_search  install_missing_dependencies",
         },
+        "set entries project location": {
+            "cli_cmd": 'python_search  set_project_location "$(collect_input --prefill_with_clipboard)"',
+        }
     }
